@@ -1,12 +1,15 @@
 """
 Exposes TfsDataFrame, read and write directly in tfs namespace, as well as the package version.
 """
-from tfs.handler import TfsDataFrame, read_tfs, write_tfs
+from tfs.errors import TfsFormatError
+from tfs.frame import TfsDataFrame, concat
+from tfs.reader import read_tfs
+from tfs.writer import write_tfs
 
 __title__ = "tfs-pandas"
 __description__ = "Read and write tfs files."
 __url__ = "https://github.com/pylhc/tfs"
-__version__ = "2.0.3"
+__version__ = "3.0.0"
 __author__ = "pylhc"
 __author_email__ = "pylhc@github.com"
 __license__ = "MIT"
@@ -15,4 +18,4 @@ __license__ = "MIT"
 read = read_tfs
 write = write_tfs
 
-__all__ = [read, write, TfsDataFrame, __version__]
+__all__ = [concat, read, write, TfsDataFrame, __version__]
